@@ -1019,20 +1019,20 @@ static int apparmor_socket_getpeersec_stream(struct socket *sock,
 	/* don't include terminating \0 in slen, it breaks some apps */
 	if (slen < 0) {
 		error = -ENOMEM;
-		goto out;
-	} else if (slen > len) {
-		error = -ERANGE;
-		goto out;
+	} else {
+		if (slen > len) {
+			error = -ERANGE;
+		} else if (copy_to_user(optval, name, slen)) {
+			error = -EFAULT;
+			goto out;
+		}
+		if (put_user(slen, optlen))
+			error = -EFAULT;
+	out:
+		kfree(name);
+
 	}
 
-	if (copy_to_user(optval, name, slen))
-		error = -EFAULT;
-
-out:
-	if (put_user(slen, optlen))
-		error = -EFAULT;
-	kfree(name);
-
 	return error;
 }
 
